<?php
/*
Plugin Name: K2 Style Switcher
Plugin URI: http://thecuriousfrog.com/projects/k2-style-switcher/
Description: This plugin allows site visitors to change the active style when the excellent K2 theme is selected.
Version: 1.0.0
Author: Hugh Johnson
Author URI: http://thecuriousfrog.com

 A lot of this code is taken directly from the K2 source files. This plugin was originally written by Kimya Hasira
 (kimya.hasira@digitaldiversified.com) who is an active contributor to the project.
*/
/*  
    Copyright 2008 Hugh Johnson  (email : hugh.johnson@thecuriousfrog.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

// Adds 'K2 Style Switcher' to 'Presentation' menu when K2 is active
if ( get_current_theme() == 'K2' ) {
    update_option('k2scheme',  '');
    function k2ss_admin_menu() {
        add_submenu_page('themes.php', 'K2 Style Switcher', 'K2 Style Switcher', 10, 'style-switcher.php', 'k2ss_admin_page');
    }
    add_action('admin_menu', 'k2ss_admin_menu');
} else {
    return;
}

// Setup all the options for the Administration Panel
$k2ss_autoload = 'yes';
add_option('k2ss_display_format', '', 'Choose how to display the styles in the sidebar module.', $k2ss_autoload);
add_option('k2ss_styles_array', '', 'Choose the styles to display in the sidebar module.', $k2ss_autoload);
add_option('k2ss_default_scheme', '', 'Replaces the default K2 scheme originally set in K2 Options.', $k2ss_autoload);
add_option('k2ss_footer_code', '', 'Replaces k2styleinfo option for Style Switcher.', $k2ss_autoload);

// Updates form options
function k2ss_updates() {
    if ( !empty($_POST) ) {
        if ( isset($_POST['k2ss_set_display']) ) {
            $k2ss_var_display = $_POST['k2ss_set_display'];
            update_option('k2ss_display_format', $k2ss_var_display, '','');
        }
        if ( isset($_POST['k2ss_set_styles']) ) {
            $k2ss_var_styles = $_POST['k2ss_set_styles'];
            update_option('k2ss_styles_array', $k2ss_var_styles, '','');
        }
        if ( isset($_POST['k2ss_set_default']) ) {
            $k2ss_var_default = $_POST['k2ss_set_default'];
            update_option('k2ss_default_scheme', $k2ss_var_default, '','');
        }
        if ( isset($_POST['k2ss_set_footer']) ) {
            $k2ss_var_footer = $_POST['k2ss_set_footer'];
            update_option('k2ss_footer_code', $k2ss_var_footer, '','');
        }
    }
}
$k2ss_updates = k2ss_updates();

// Displays the page content for the Administration Panel
function k2ss_admin_page() {

// Commented out lines in this set are a trouble-shooting aid.
// Uncommenting them shouldn't break anything, but don't.
if ( isset($_POST['Submit']) ) {
    // $k2ss_get_display = get_option(k2ss_display_format);
    // $k2ss_get_styles = get_option(k2ss_styles_array);
    // $k2ss_get_default = get_option(k2ss_default_scheme);
    // $k2ss_get_footer = get_option(k2ss_footer_code);
    echo('<div class="updated">');
    echo('<p>K2 Style Switcher options have been updated.</p>');
    // echo('<p>Display: ' . $k2ss_get_display . '</p>');
    // echo('<p>Styles: '); print_r($k2ss_get_styles); echo('</p>');
    // echo('<p>Default: ' . $k2ss_get_default . '</p>');
    // echo('<p>Footer: ' . $k2ss_get_footer . '</p>');
    echo('</div>');
} ?>

<div class="wrap">
    <h2>K2 Style Switcher</h2>
    <form name="k2ss_admin_form" action="" method="post">
        <input type="hidden" name="action" value="$k2ss_updates" />
        <table class="editform" cellspacing="5">
            <tr valign="top">
                <th>Display</th>
                <td colspan="3">

                    <input name="k2ss_set_display" id="list" type="radio" value="list"
                    <?php checked('list', get_option('k2ss_display_format')); ?> />
                    <label for="list">Unordered List</label>

                    <?php echo(' &nbsp; &nbsp; &nbsp; '); ?>

                    <input name="k2ss_set_display" id="menu" type="radio" value="menu"
                    <?php checked('menu', get_option('k2ss_display_format')); ?> />
                    <label for="menu">Dropdown Menu</label>

                    <p><small>This option controls the way the sidebar module displays the styles list.</small></p>
                </td>
            </tr>
            <tr valign="top">
                <th style="width: 100px;">Styles</th>
                <th style="text-align: center; background: #F5F5F5; width: 200px;">Name</th>
                <th style="text-align: center; background: #F5F5F5; width: 100px;">Version</th>
                <th style="text-align: center; background: #F5F5F5; width: 300px;">Comments</th>
            </tr>

<?php

// Get the scheme files
$scheme_files = array();

// Is this WPMU or no?
define('K2SS_MU', (isset($wpmu_version) or (strpos($wp_version, 'wordpress-mu') !== false)));

if ( K2SS_MU ) {
    $schemes_path = ABSPATH . UPLOADS . 'k2support/styles/';
} else {
    $schemes_path = TEMPLATEPATH . '/styles/';
}

// Scan for themes
if ( ($dir = @dir($schemes_path)) !== false ) {
    while ( ($file = $dir->read()) !== false ) {
        if ( is_dir($schemes_path . $file) && !preg_match('/^\.+$/i', $file) ) {
            $schemes_subpath = $schemes_path . $file . '/';
            if ( ($sub_dir = @dir($schemes_subpath)) !== false ) {
                while ( ($sub_file = $sub_dir->read()) !== false ) {
                    if ( is_file($schemes_subpath . $sub_file) && preg_match('/\.css$/i', $sub_file) ) {
                        $scheme_files[] = $file . '/' . $sub_file;
                    }
                }
                $sub_dir->close();
            }
        } elseif ( is_file($schemes_path . $file) && preg_match('/\.css$/i', $file) ) {
            $scheme_files[] = $file;
        }
    }
    $dir->close();
}

natcasesort($scheme_files);
foreach($scheme_files as $scheme_file) {

            echo('<tr valign="top">');
                echo('<th>  </th>');
                echo('<td style="background: #F5F5F5;">');

                    echo('<input name="k2ss_set_styles[]" type="checkbox" value="' . $scheme_file . '"');
                    $os = get_option('k2ss_styles_array');
                    if ( !empty($os) ) {
                        if ( in_array("$scheme_file", $os) ) {
                            echo('checked="checked"');
                        }
                    }
                    echo(' />');

                    // Parse the stylesheets for the style information
                    if ( K2SS_MU ) {
                        $k2ss_style_path = ABSPATH . UPLOADS . 'k2support/styles/' . $scheme_file;
                    } else {
                        $k2ss_style_path = TEMPLATEPATH . '/styles/' . $scheme_file;
                    }
                    $k2ss_style_data = implode( '', file( $k2ss_style_path ) );

                    preg_match("|Style Name\s*:(.*)|i", $k2ss_style_data, $style);
                    preg_match("|Style URI\s*:(.*)|i", $k2ss_style_data, $stylelink);
                    preg_match("|Version\s*:(.*)|i", $k2ss_style_data, $version);
                    preg_match("|Comments\s*:(.*)|i", $k2ss_style_data, $comments);

                    $style = $style[1];
                    $stylelink = $stylelink[1];
                    $version = $version[1];
                    $comments = $comments[1];

                    // Output the label using the style information
                    if ( empty($style) ) {
                        echo($scheme_file);
                    } elseif ( empty($stylelink) ) {
                        echo($style);
                    } else {
                        echo('<a href="' . $stylelink . '">' . $style . '</a>');
                    }

                echo('</td>');
                echo('<td style="background: #F5F5F5; text-align: center; ">');

                    if ( empty($version) ) {
                        echo('');
                    } else {
                        echo($version);
                    }

                echo('</td>');
                echo('<td style="background: #F5F5F5;">');

                    if ( empty($comments) ) {
                        echo('');
                    } else {
                        echo($comments);
                    }
                echo('</td>');
            echo('</tr>');
} // end foreach ?>

            <tr>
                <th> </th>
                <td colspan="3">
                    <p><small>Select the styles you want website visitors to be able to use.
                    Click on the style name to visit the style website.</small></p>
                </td>
            </tr>
            <tr valign="top">
                <th>Default</th>
                <td colspan="3">
                    <select name="k2ss_set_default" style="width: 300px; ">
                    <?php foreach($scheme_files as $scheme_file) {
                        echo('<option value="' . $scheme_file . '"');
                        if ($scheme_file == get_option('k2ss_default_scheme')) {
                            echo(' selected');
                        }
                    echo('>' . $scheme_file . '</option>'); } ?>
                    </select>
                    <p><small>Choose the default style. This will replace the 'K2 Scheme' in the 'K2 Options' tab.</small></p>
                </td>
            </tr>
            <tr valign="top">
                <th>Footer</th>
                <td colspan="3">
                    <textarea name="k2ss_set_footer" rows="5" cols="83"><?php echo(stripslashes(get_option('k2ss_footer_code'))); ?></textarea>
                    <p><small>Your footer will display as: </small></p><?php k2ss_display_footer(); ?>
                </td>
            </tr>
        </table>
        <p class="submit"><input type="submit" name="Submit" value="Update Options" /></p>
    </form>
</div>

<div class="wrap">
    <p style="text-align: center;">Need help? You can view the plugin documentation or ask questions <a
    href="http://digitaldiversified.com/archives/style-switcher.html">here</a>.</p>
</div>

<?php } // end function k2ss_admin_page

// Is this WPMU or no?
define('K2SS_MU', (isset($wpmu_version) or (strpos($wp_version, 'wordpress-mu') !== false)));

// Places the Style Switcher in the K2 Sidebar
function k2ss_sidebar() {
    $k2ss_sb_check = get_current_theme();
    if ($k2ss_sb_check == 'K2') {
        $k2ss_sb_display = get_option('k2ss_display_format');
        $k2ss_sb_styles = get_option('k2ss_styles_array');
        $k2ss_sb_default = get_option('k2ss_default_scheme');
        natcasesort($k2ss_sb_styles);

        if ($k2ss_sb_display == 'list') {
            echo('<ul>');
            echo('
                <script language="JavaScript" type="text/javascript">
                <!--
                function k2ss_script ( selectedtype )
                {
                document.k2ss_sb_form.k2ss_set_style.value = selectedtype ;
                document.k2ss_sb_form.submit() ;
                }
                -->
                </script>
            ');
                echo('<form name="k2ss_sb_form" action="' . $k2ss_switch_action . '" method="post">');
                    echo('<input type="hidden" name="k2ss_set_style" />');

                    foreach($k2ss_sb_styles as $k2ss_sb_style) {

                        // Parse the stylesheets for the style information
                        if ( K2SS_MU ) {
                            $k2ss_sb_path = ABSPATH . UPLOADS . 'k2support/styles/' . $k2ss_sb_style;
                        } else {
                            $k2ss_sb_path = TEMPLATEPATH . '/styles/' . $k2ss_sb_style;
                        }
                        $k2ss_sb_data = implode( '', file( $k2ss_sb_path ) );
                        preg_match("|Style Name\s*:\s*(.*)|i", $k2ss_sb_data, $k2ss_sb_name);
                        $k2ss_sb_name = $k2ss_sb_name[1];

                        if (!empty($k2ss_sb_name)) {
                            if (!empty($_SESSION['k2ss_get_style'])) {
                                if ($_SESSION['k2ss_get_style'] == $k2ss_sb_style) {
                                    echo('<li class="k2ss_selected"><a href="javascript:k2ss_script(\'' . $k2ss_sb_style . '\')">' . $k2ss_sb_name . '</a></li>');
                                } else {
                                    echo('<li><a href="javascript:k2ss_script(\'' . $k2ss_sb_style . '\')">' . $k2ss_sb_name . '</a></li>');
                                }
                            } else {
                                if ($k2ss_sb_default == $k2ss_sb_style) {
                                    echo('<li class="k2ss_selected"><a href="javascript:k2ss_script(\'' . $k2ss_sb_style . '\')">' . $k2ss_sb_name . '</a></li>');
                                } else {
                                    echo('<li><a href="javascript:k2ss_script(\'' . $k2ss_sb_style . '\')">' . $k2ss_sb_name . '</a></li>');
                                }
                            }
                        } else {
                            if (!empty($_SESSION['k2ss_get_style'])) {
                                if ($_SESSION['k2ss_get_style'] == $k2ss_sb_style) {
                                    echo('<li class="k2ss_selected"><a href="javascript:k2ss_script(\'' . $k2ss_sb_style . '\')">' . $k2ss_sb_style . '</a></li>');
                                } else {
                                    echo('<li><a href="javascript:k2ss_script(\'' . $k2ss_sb_style . '\')">' . $k2ss_sb_style . '</a></li>');
                                }
                            } else {
                                if ($k2ss_sb_default == $k2ss_sb_style) {
                                    echo('<li class="k2ss_selected"><a href="javascript:k2ss_script(\'' . $k2ss_sb_style . '\')">' . $k2ss_sb_style . '</a></li>');
                                } else {
                                    echo('<li><a href="javascript:k2ss_script(\'' . $k2ss_sb_style . '\')">' . $k2ss_sb_style . '</a></li>');
                                }
                            }
                        }

                        } // end foreach

                echo('</form>');
            echo('</ul>');
        } elseif ($k2ss_sb_display == 'menu') {
            echo('<div>');
                echo('<form action=" " method="post">');
                    echo('<input type="hidden" name="action" value="' . $k2ss_switch_action . '" />');
                    echo('<select name="k2ss_set_style">');

                    foreach($k2ss_sb_styles as $k2ss_sb_style) {

                    // Parse the stylesheets for the style information
                    if ( K2SS_MU ) {
                        $k2ss_sb_path = ABSPATH . UPLOADS . 'k2support/styles/' . $k2ss_sb_style;
                    } else {
                        $k2ss_sb_path = TEMPLATEPATH . '/styles/' . $k2ss_sb_style;
                    }
                    $k2ss_sb_data = implode( '', file( $k2ss_sb_path ) );
                    preg_match("|Style Name\s*:\s*(.*)|i", $k2ss_sb_data, $k2ss_sb_name);
                    $k2ss_sb_name = $k2ss_sb_name[1];

                        if (!empty($k2ss_sb_name)) {
                            if (!empty($_SESSION['k2ss_get_style'])) {
                                if ($_SESSION['k2ss_get_style'] == $k2ss_sb_style) {
                                    echo('<option value="' . $k2ss_sb_style . '" selected>' . $k2ss_sb_name . '</option>');
                                } else {
                                    echo('<option value="' . $k2ss_sb_style . '">' . $k2ss_sb_name . '</option>');
                                }
                            } else {
                                if ($k2ss_sb_default == $k2ss_sb_style) {
                                    echo('<option value="' . $k2ss_sb_style . '" selected>' . $k2ss_sb_name . '</option>');
                                } else {
                                    echo('<option value="' . $k2ss_sb_style . '">' . $k2ss_sb_name . '</option>');
                                }
                            }
                        } else {
                            if (!empty($_SESSION['k2ss_get_style'])) {
                                if ($_SESSION['k2ss_get_style'] == $k2ss_sb_style) {
                                    echo('<option value="' . $k2ss_sb_style . '" selected>' . $k2ss_sb_style . '</option>');
                                } else {
                                    echo('<option value="' . $k2ss_sb_style . '">' . $k2ss_sb_style . '</option>');
                                }
                            } else {
                                if ($k2ss_sb_default == $k2ss_sb_style) {
                                    echo('<option value="' . $k2ss_sb_style . '" selected>' . $k2ss_sb_style . '</option>');
                                } else {
                                    echo('<option value="' . $k2ss_sb_style . '">' . $k2ss_sb_style . '</option>');
                                }
                            }
                        }

                    } // end foreach

                    echo('</select>');
                    echo('<input type="submit" value="go!" style="border: 1px solid Silver; margin: 0 0 0 2px;" />');
                echo('</form>');
            echo('</div>');
        }

    } else {
        echo('Your current theme is ' . $k2ss_check . '. This plugin will only work with K2. Activate K2 and try again.');
        return;
    }
}

// Creates php session to store user selected style
function k2ss_switch_action() {
    if ( !empty($_POST) ) {
        if ( isset($_POST['k2ss_set_style']) ) {
            $_SESSION['k2ss_get_style'] = $_POST['k2ss_set_style'];
        }
    }
    session_start();
}
add_action('init', 'k2ss_switch_action');
$k2ss_switch_action = k2ss_switch_action();

// Adds custom stylesheet to header
function k2ss_change_style() {
    if (!isset($_SESSION['k2ss_get_style'])) {
        $k2ss_cs_data = get_option('k2ss_default_scheme');
    } else {
        $k2ss_cs_data = $_SESSION['k2ss_get_style'];
    }
    if ( K2SS_MU ) {
        $k2ss_cs_path = get_bloginfo('wpurl') . '/' . UPLOADS . 'k2support/styles/' . $k2ss_cs_data;
    } else {
        $k2ss_cs_path = get_bloginfo('stylesheet_directory') . '/styles/' . $k2ss_cs_data;
    }
    echo('<link rel="stylesheet" type="text/css" media="screen" href="' . $k2ss_cs_path . '" />');
}
add_action('wp_head', 'k2ss_change_style');

// Displays footer on page. Plugin disables default k2 scheme so a replacement footer was needed.
function k2ss_display_footer() {
    if ( isset($_SESSION['k2ss_get_style']) ) {
        $k2ss_df_file = $_SESSION['k2ss_get_style'];
    } else {
        $k2ss_df_file = get_option('k2ss_default_scheme');
    }
    if ( K2SS_MU ) {
        $k2ss_df_path = ABSPATH . UPLOADS . 'k2support/styles/' . $k2ss_df_file;
    } else {
        $k2ss_df_path = TEMPLATEPATH . '/styles/' . $k2ss_df_file;
    }
    $k2ss_df_data = implode( '', file( $k2ss_df_path ) );

    // parse the data
    preg_match("|Author Name\s*:\s*(.*)|i", $k2ss_df_data, $author);
    preg_match("|Author Site\s*:\s*(.*)|i", $k2ss_df_data, $site);
    preg_match("|Style Name\s*:\s*(.*)|i", $k2ss_df_data, $style);
    preg_match("|Style URI\s*:\s*(.*)|i", $k2ss_df_data, $stylelink);
    preg_match("|Version\s*:\s*(.*)|i", $k2ss_df_data, $version);
    preg_match("|Comments\s*:\s*(.*)|i", $k2ss_df_data, $comments);

    $k2ss_sf_root = get_bloginfo('home');
    preg_match("|(.*)/.*\.css|i", $k2ss_df_file, $k2ss_sf_file);
    $k2ss_sf_file = preg_replace('/\s/', '', $k2ss_sf_file);
    $k2ss_sf_file = $k2ss_sf_file[1];
    $stylefolderpath = $k2ss_sf_root . '/wp-content/themes/k2/styles/' . $k2ss_sf_file;

    $bloginfoname = get_bloginfo('name');
    $bloginfoversion = get_bloginfo('version');
    $k2infoversion = get_k2info('version');
    $podpressversion = get_option('podPress_version');
    $templatepath = $k2ss_sf_root . '/wp-content/themes/k2';
    $rssentries = get_bloginfo('rss2_url');
    $rsscomments = get_bloginfo('comments_rss2_url');

    $author = $author[1];
    $site = $site[1];
    $style = $style[1];
    $stylelink = $stylelink[1];
    $version = $version[1];
    $comments = $comments[1];

    $k2ss_df_code = stripslashes(get_option('k2ss_footer_code'));

    $k2ss_df_code = str_replace("%stylefolderpath%", $stylefolderpath, $k2ss_df_code);

    $k2ss_df_code = str_replace("%bloginfoname%", $bloginfoname, $k2ss_df_code);
    $k2ss_df_code = str_replace("%bloginfoversion%", $bloginfoversion, $k2ss_df_code);
    $k2ss_df_code = str_replace("%k2infoversion%", $k2infoversion, $k2ss_df_code);
    $k2ss_df_code = str_replace("%podpressversion%", $podpressversion, $k2ss_df_code);
    $k2ss_df_code = str_replace("%templatepath%", $templatepath, $k2ss_df_code);
    $k2ss_df_code = str_replace("%rssentries%", $rssentries, $k2ss_df_code);
    $k2ss_df_code = str_replace("%rsscomments%", $rsscomments, $k2ss_df_code);

    $k2ss_df_code = str_replace("%author%", $author, $k2ss_df_code);
    $k2ss_df_code = str_replace("%site%", $site, $k2ss_df_code);
    $k2ss_df_code = str_replace("%style%", $style, $k2ss_df_code);
    $k2ss_df_code = str_replace("%stylelink%", $stylelink, $k2ss_df_code);
    $k2ss_df_code = str_replace("%version%", $version, $k2ss_df_code);
    $k2ss_df_code = str_replace("%comments%", $comments, $k2ss_df_code);

    echo('<p id="k2ss_footer">' . $k2ss_df_code . '</p>');

}
add_action('wp_footer', 'k2ss_display_footer');

?>